@@ -8,14 +8,10 @@ from pydantic_settings import BaseSettings, SettingsConfigDict
 
 
 class Settings(BaseSettings):
-    model_config = SettingsConfigDict(
-        env_prefix="bitrix24_api_",
-        env_file=".env",
-        extra="ignore",
-    )
-
     webhook_url: HttpUrl
 
+    http_timeout: int = 30
+
     retry_statuses: list[int] = (
         codes.LOCKED,
         codes.TOO_EARLY,
@@ -27,15 +23,21 @@ class Settings(BaseSettings):
     )
     retry_errors: list[str] = ["query_limit_exceeded", "operation_time_limit"]
 
-    retry_tries: int = 5
+    retry_attempts: int = 5
     retry_delay: float = 5
     retry_backoff: float = 2
 
     list_size: int = 50
     batch_size: int = 50
 
+    model_config = SettingsConfigDict(
+        env_prefix="bitrix24_api_",
+        env_file=".env",
+        extra="ignore",
+    )
 
-def api_settings(**kwargs: dict) -> Generator[Settings, None, None]:
+
+def api_settings(**kwargs: dict) -> Generator[Settings]:
     settings = Settings(**kwargs)
     yield settings
 
